@@ -39,7 +39,8 @@ class EditorMain(object):
         self.auto_save_thread = start_auto_save(self.auto_save_thread, self.current_file, self.code_editor_textarea)
         if self.debug_run:
             self.close_event()
-        self.main_window.mainloop()
+        else:
+            self.main_window.mainloop()
 
     # editor close event
     def close_event(self):
@@ -126,14 +127,10 @@ class EditorMain(object):
         except JEditorContentFileException as error:
             print(repr(error), file=sys.stderr)
         self.highlight_text.search()
-        print("language_compiler_param: " + str(language_compiler_param))
-        print("language_compiler: " + str(language_compiler))
-        print("language_list: " + str(language_list))
 
     # default event
     def do_test(self, event=None):
-        self.debug_run = True
-        print("test")
+        print(self.debug_run)
 
     def __init__(self, use_theme=None, debug=False, main_window=Tk()):
         """
